CaptchaPluginConfig class

Constructors

CaptchaPluginConfig({int? radius, String? capBarTextAlign, String? capBarBorderColor, String? capBarTextColor, int? capBarTextSize, String? capBarTextWeight, int? capBarTitleHeight, int? capBodyPadding, int? capPaddingTop, int? capPaddingRight, int? capPaddingBottom, int? capPaddingLeft, int? paddingTop, int? paddingBottom, int? capBorderRadius, String? borderColor, String? background, String? borderColorMoving, String? backgroundMoving, String? borderColorSuccess, String? backgroundSuccess, String? backgroundError, String? borderColorError, String? slideBackground, int? textSize, String? textColor, int? height, int? borderRadius, String? gap, int? executeBorderRadius, String? executeBackground, String? executeTop, String? executeRight})

Properties

background → String?
final
backgroundError → String?
final
backgroundMoving → String?
final
backgroundSuccess → String?
final
borderColor → String?
final
borderColorError → String?
final
borderColorMoving → String?
final
borderColorSuccess → String?
final
borderRadius → int?
final
capBarBorderColor → String?
final
capBarTextAlign → String?
final
capBarTextColor → String?
final
capBarTextSize → int?
final
capBarTextWeight → String?
弹框头部标题文字字体体重,可设置粗细, 参考:capBarTextWeight: normal、bold、lighter、bolder、100、200、300、400、500、600、700、800、900 更多详情参考:https://developer.mozilla.org/en-US/docs/Web/CSS/font-weight
final
capBarTitleHeight → int?
final
capBodyPadding → int?
final
capBorderRadius → int?
final
capPaddingBottom → int?
final
capPaddingLeft → int?
final
capPaddingRight → int?
final
capPaddingTop → int?
final
executeBackground → String?
final
executeBorderRadius → int?
final
executeRight → String?
final
executeTop → String?
final
gap → String?
final
hashCode → int
The hash code for this object.
no setterinherited
height → int?
final
paddingBottom → int?
final
paddingTop → int?
final
radius ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
slideBackground → String?
final
textColor → String?
final
textSize → int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited